pub struct Japanese {
eras: DataPayload<CalendarJapaneseModernV1>,
}Expand description
The Japanese Calendar (with modern eras only)
The Japanese Calendar is a variant of the Gregorian calendar
created by the Japanese government. It is identical to the Gregorian calendar except that
is uses Japanese eras instead of the Common Era.
This implementation extends proleptically for dates before the calendar’s creation in 6 Meiji (1873 CE). The Meiji era is used proleptically back to and including 1868-10-23, Gregorian eras are used before that.
For a variant that uses approximations of historical Japanese eras proleptically, check out JapaneseExtended.
This corresponds to the "japanese" CLDR calendar.
Era codes
This calendar currently supports seven era codes. It supports the five eras since its
introduction (meiji, taisho, showa, heisei, reiwa), as well as the Gregorian
bce (alias bc), and ce (alias ad) for earlier dates.
Future eras will also be added to this type when they are decided.
These eras are loaded from data, requiring a data provider capable of providing CalendarJapaneseModernV1
data.
Fields
eras: DataPayload<CalendarJapaneseModernV1>Implementations
Sourceimpl Japanese
impl Japanese
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new Japanese using only modern eras (post-meiji) from compiled data.
✨ Enabled with the compiled_data Cargo feature.
Sourcepub fn try_new_unstable<D: DataProvider<CalendarJapaneseModernV1> + ?Sized>(
provider: &D,
) -> Result<Self, DataError>
pub fn try_new_unstable<D: DataProvider<CalendarJapaneseModernV1> + ?Sized>( provider: &D, ) -> Result<Self, DataError>
A version of Self::new that uses custom data provided by a DataProvider.